# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_excel.py
# Author:        liunian
# Datetime:      2024/1/6 9:46
# Description:
# 
# ---------------------------------------------------------------------------
import os.path

import openpyxl

from APITestFrame1.common.read_ini import Read_ini
from APITestFrame1.common.read_json import read_json
from APITestFrame1.data_config.settings import *


class Read_excel:
    def __init__(self, excel_path, case_path, expect_path, sql_path, table_name):
        """根据传入的文件路径，读取文件中的内容"""
        self.case_data = read_json(case_path)
        self.expect_data = read_json(expect_path)
        self.sql_data = read_json(sql_path)

        try:
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except:
            raise ValueError("传入的excel路径或者工作表的名称错误")

    def __get_cell_value(self, column: str, row: int):
        """获取单元格的值"""
        try:
            cell_value = self.ws[column + str(row)].value
        except:
            raise ValueError("传入的列号或行号错误")
        else:
            if cell_value is None:
                return None
            elif cell_value:
                return cell_value.strip()

    def get_module_name(self, row):
        """获取模块名称"""
        return self.__get_cell_value(MODULE_NAME, row)

    def get_API_name(self, row):
        """获取接口名称"""
        return self.__get_cell_value(API_NAME, row)

    def get_title_name(self, row):
        """获取标题名称"""
        return self.__get_cell_value(TITLE, row)

    def get_case_level(self, row):
        """获取用例等级"""
        return self.__get_cell_value(LEVEL, row)

    def get_request_method(self, row):
        """获取请求方法"""
        return self.__get_cell_value(REQUEST_METHOD, row)

    def get_url_path(self, row):
        """获取请求URL"""
        res = self.__get_cell_value(PATH, row)
        if res:
            return Read_ini().get_host(SYSTEM_URL) + res

    def get_media_type(self, row):
        """获取媒体类型"""
        res = self.__get_cell_value(MIME, row)
        if res:
            return res.lower()

    def get_case_data(self, row):
        """获取用例数据"""
        res = self.__get_cell_value(CASE_DATA, row)
        if res:
            module_name = self.get_module_name(row)
            API_name = self.get_API_name(row)
            return self.case_data[module_name][API_name][res]

    def get_expect_data(self, row):
        """获取期望数据"""
        res = self.__get_cell_value(EXPECT_DATA, row)
        if res:
            module_name = self.get_module_name(row)
            API_name = self.get_API_name(row)
            return self.expect_data[module_name][API_name][res]

    def get_sql_type(self, row):
        """获取sql语句类型"""
        res = self.__get_cell_value(SQL_TYPE, row)
        if res:
            return res.lower()

    def get_sql_content(self, row):
        """获取sql语句"""
        res = self.__get_cell_value(SQL_DATA, row)
        if res:
            module_name = self.get_module_name(row)
            API_name = self.get_API_name(row)
            return self.sql_data[module_name][API_name][res]

    def get_update_key(self, row):
        """获取更新的key"""
        return self.__get_cell_value(UPDATE_KEY, row)

    def datas(self):
        result = []
        for row in range(2, self.ws.max_row + 1):
            get_module_name=self.get_module_name(row)
            get_API_name = self.get_API_name(row)
            get_title_name = self.get_title_name(row)
            get_case_level = self.get_case_level(row)
            get_request_method = self.get_request_method(row)
            get_url_path = self.get_url_path(row)
            get_media_type = self.get_media_type(row)
            get_case_data = self.get_case_data(row)
            get_expect_data = self.get_expect_data(row)
            get_sql_type = self.get_sql_type(row)
            get_sql_content = self.get_sql_content(row)
            get_update_key = self.get_update_key(row)
            res_list = [get_module_name,get_API_name, get_title_name, get_case_level, get_request_method, get_url_path, get_media_type,
                        get_case_data, get_expect_data, get_sql_type, get_sql_content, get_update_key]
            if res_list.count(None) <= 5:
                result.append(res_list)
        else:
            return result


if __name__ == '__main__':
    dirname_path = os.path.join(os.path.join(os.path.dirname(os.path.dirname(__file__)), "data_config"),
                                "data_template")
    case_path = os.path.join(dirname_path, "case_data.json")
    expect_path = os.path.join(dirname_path, "expect_data.json")
    sql_path = os.path.join(dirname_path, "sql_data.json")
    excel_path = os.path.join(dirname_path, "APIAutoTest.xlsx")
    table_name = "BPM"
    print(Read_excel(excel_path, case_path, expect_path, sql_path, table_name).datas())
